# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "index.md",
    "API Reference" => [
        "Native Functionalities" => "api/native.md",
    ],
    "Wrapped Algorithms API" => [
        "LineSearches.jl" => "api/line_searches.md",
    ],
    "References" => "references.md",
]
